@@ -11,14 +11,14 @@ class CivetQCError(Exception):
 class ColumnNotFoundError(CivetQCError):
     """ raised when a required column is not found when reading a CSV file """
 
-    def __init__(self, colname: str, filepath: Path) -> None:
+    def __init__(self, colname: str, filepath: Path | str) -> None:
         super().__init__(f"Required column '{colname}' not found in file: {filepath}")
 
 
 class NonNumericValueError(CivetQCError):
     """ raised when a value that cannot be converted to float is encountered while reading CSV file """
 
-    def __init__(self, colname: str, value: str, filepath: Path) -> None:
+    def __init__(self, colname: str, value: str, filepath: Path | str) -> None:
         super().__init__(f"Unexpected non-numeric value '{value}' for column '{colname}' in file: {filepath}")
 
 
